@@ -541,9 +541,9 @@ class PC(object):
 
 
 class Mobile(object):
-    """通过移动端的wechat，获取需要爬取的微信公众号的推文链接"""
+    """已失效。通过移动端的wechat，获取需要爬取的微信公众号的推文链接"""
 
-    def __init__(self, biz, cookie):
+    def __init__(self, biz, cookie, proxies={"http": None, "https": None}):
         """
         Parameters
         ----------
@@ -558,6 +558,7 @@ class Mobile(object):
             "User-Agent": "Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0Chrome/57.0.2987.132 MQQBrowser/6.2 Mobile",
             "Cookie": cookie,
         }
+        self.proxies = proxies
 
     def get_urls(self, appmsg_token, offset="0"):
         """
@@ -567,7 +568,7 @@ class Mobile(object):
             个人微信号登陆后获取的token
         offset: str or int
             获取起始的页数，从0开始，每次递增10（可以大于10，但是不好确认参数，所以递增10，之后再去重）
-        
+
         Returns
         ----------
         list:
@@ -669,3 +670,10 @@ class WeBook(object):
         else:
             print(res.json())
             return []
+
+
+if __name__ == "__main__":
+    biz = ""
+    cookie = ""
+    m = Mobile(biz, cookie)
+    m.get_urls()
