@@ -4,12 +4,10 @@
 """
 import base64
 import html
-import json
 import os
 import re
 import time
-
-import requests
+import glob
 
 from .ArticlesUrls import PC
 
@@ -54,6 +52,23 @@ def remove_duplicate_json(fname):
         f.writelines(sort_data)
 
 
+def merge_duplicate_json():
+    f_lst = glob.glob("*.json")
+    for fname in f_lst:
+        with open(fname, "r", encoding="utf-8") as f:
+            data = f.readlines()
+        print(fname)
+        flag = True
+        for i in range(len(data)):
+            for j in range(i + 1, len(data)):
+                if data[i] == data[j]:
+                    flag = False
+                    print(i)
+                    break
+            if flag == False:
+                break
+
+
 def end_func(timestamp, end_timestamp):
     if timestamp < end_timestamp:
         print(timestamp, end_timestamp)
@@ -82,9 +97,12 @@ def save_f(fname):
 verify_lst = ["mp.weixin.qq.com", "__biz", "mid", "idx"]
 
 
-def verify_url(article_url):
+def verify_url(url):
+    # 过滤特殊链接
+    if "video?" in url or "show?" in url:
+        return False
     for string in verify_lst:
-        if string not in article_url:
+        if string not in url:
             return False
     return True
 
@@ -194,14 +212,17 @@ def swap_biz_id(biz=None, fakeid=None):
 
 
 # 一些tools，如时间戳转换
-def timestamp2date(timestamp):
+def timestamp2date(timestamp, time_format_str="%Y-%m-%d"):
     """
     时间戳转换为日期
 
     Parameters
     ----------
     timestamp: int or str
-        用户账号
+        时间戳
+        
+    time_format_str: str
+        转换日期格式, "%Y-%m-%d %H:%M:%S"; "%Y-%m-%d; %Y年%m月%d日%H时%M分%S秒
 
     Returns
     -------
@@ -209,5 +230,5 @@ def timestamp2date(timestamp):
         转换好的日期：年-月-日 时:分:秒
     """
     time_array = time.localtime(int(timestamp))
-    datetime = time.strftime("%Y-%m-%d %H:%M:%S", time_array)
-    return datetime
\ No newline at end of file
+    datetime = time.strftime(time_format_str, time_array)
+    return datetime
